# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information
import datetime


def _get_version():
    with open("../../VERSION") as f:
        return f.read().strip()


now = datetime.datetime.today()

# The full project version, used as the replacement for |release| and e.g. in the HTML templates.
# For example, for the Python documentation, this may be something like 2.6.0rc1.
# If you don’t need the separation provided between version and release, just set them both to the same value.
release = _get_version()


project = 'RhodeCode rcstack'
copyright = f'2010-{now.year}, RhodeCode Inc.'
author = 'RhodeCode Inc.'

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.intersphinx',
    'sphinx.ext.todo',
    'sphinx.ext.imgmath'
]

templates_path = ['_templates']
exclude_patterns = []

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

# https://github.com/pradyunsg/furo/tree/main/src/furo/theme/furo
html_theme = 'furo'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
# using the given strftime format.
html_last_updated_fmt = ' %H:%m %b %d, %Y'

# If true, "Created using Sphinx" is shown in the HTML footer. Default is True.
html_show_sphinx = False

html_extra_path = ['extra']


rst_epilog = '''
.. |RCCEshort| replace:: Community
.. |RCEEshort| replace:: Enterprise
.. |git| replace:: Git
.. |hg| replace:: Mercurial
.. |svn| replace:: Subversion

.. |RCC| replace:: RhodeCode Control
.. |RCE| replace:: RhodeCode Enterprise
.. |RCCE| replace:: RhodeCode Community
.. |RCEE| replace:: RhodeCode Enterprise
.. |RCT| replace:: RhodeCode Tools

.. |RCEBOLD| replace:: **RhodeCode Enterprise**
.. |RCEITALICS| replace:: `RhodeCode Enterprise`
'''
